///////////////////////////////////////////////////////////////////////////////
//
// File:    global.h
// Author:  Roger Rowland
//
// Created: December 2014
//
///////////////////////////////////////////////////////////////////////////////

#ifndef GLOBAL_H
#define	GLOBAL_H

// global includes
#include <stdint.h>

///////////////////////////////////////////////////////////////////////////////
// definitions for delay macros
///////////////////////////////////////////////////////////////////////////////

#define _XTAL_FREQ  32000000L                   // oscillator frequency 32MHz

///////////////////////////////////////////////////////////////////////////////
// definitions for sensor configuration
///////////////////////////////////////////////////////////////////////////////

#define SENSOR_16H      0x12                    // 16 hourly frequency
#define SENSOR_8H       0x11                    // 8 hourly frequency
#define SENSOR_4H       0x10                    // 4 hourly frequency
#define SENSOR_2H       0x0F                    // 2 hourly frequency
#define SENSOR_1H       0x0E                    // hourly frequency
#define SENSOR_30M      0x0D                    // 30 minute frequency
#define SENSOR_15M      0x0C                    // 15 minute frequency
#define SENSOR_1M       0x08                    // 1 minute frequency
#define SENSOR_30S      0x07                    // 30 second frequency
#define SENSOR_15S      0x06                    // 15 second frequency

#define SENSOR_ID       0x01                    // sensor id
#define DFT_CONFIG      SENSOR_15M              // default config
#define WATCHDOG_SCALE  225                     // watchdog scaling

// structure for sensor data
typedef struct
{
    uint8_t uId;                                // id of this sensor node
    uint8_t uConfig;                            // sensor node configuration
    int16_t nReading1;                          // adc reading 1
    int16_t nReading2;                          // adc reading 2
    uint16_t uSequence;                         // sequence number
} SensorData;

///////////////////////////////////////////////////////////////////////////////
// define nRF24l01+ pins
///////////////////////////////////////////////////////////////////////////////

#define NRF_CSN             LATAbits.LATA0      // nRF24l01+ CSN
#define NRF_CSN_TRIS        TRISA0              // nRF24l01+ CSN TRIS
#define NRF_CE              LATAbits.LATA1      // nRF24l01+ CE
#define NRF_CE_TRIS         TRISA1              // nRF24l01+ CE TRIS

///////////////////////////////////////////////////////////////////////////////
// useful typedefs
///////////////////////////////////////////////////////////////////////////////

typedef union                                   // 16-bit short as two 8-bit bytes
{
    uint16_t uShort;                            // unsigned short
    int16_t nShort;                             // signed short
    struct
    {
        uint8_t uLSB;                           // least significant byte
        uint8_t uMSB;                           // most significant byte
    };
} t_short;

#endif	/* GLOBAL_H */

